@@ -15,20 +15,30 @@ test_that("update_collate() checks that directory exists", {
 })
 
 test_that("Collate field unchanged when no @includes", {
-  local_package_copy(test_path('testCollateNoIncludes'))
+  path <- local_package_copy(test_path('testCollateNoIncludes'))
 
-  update_collate(".")
-  expect_equal(desc::desc_get_field("Collate"), "b.r a.r")
+  update_collate(path)
+  expect_equal(desc::desc_get_field("Collate", file = path), "b.R a.R")
 })
 
 test_that("DESCRIPTION file is re-written only if collate changes", {
-  local_package_copy(test_path("testCollateOverwrite"))
+  path <- local_package_copy(test_path("testCollateOverwrite"))
 
   expect_snapshot({
-    update_collate(".")
+    update_collate(path)
     "Second run should be idempotent"
-    update_collate(".")
-  })
+    update_collate(path)
+  }, transform = function(x) gsub(path, "<path>", x, fixed = TRUE))
+})
+
+test_that("drops bad collect directives", {
+  path <- local_package_copy(test_path("empty"))
+  write_lines(c("#' @include foo", "NULL"), file.path(path, "R", "a.R"))
+  write_lines(c("#' @include a.R", "NULL"), file.path(path, "R", "b.R"))
+  unlink(file.path(path, "R/empty-package.R"))
+
+  withr::with_dir(path, expect_snapshot(update_collate(".")))
+  expect_equal(desc::desc_get_collate(file = path), c("a.R", "b.R"))
 })
 
 test_that("can read from file name with utf-8 path", {
